/**
 * @file
 * Site preview.
 */

(function($, window, Drupal, drupalSettings) {
  $.fn.drupalAjax = (url) => {
    const ajaxSettings = {
      url,
      dialogRenderer: 'off_canvas',
      dialogType: 'dialog',
      // @todo make width configurable and pass via drupalSettings
      dialog: { width: 480 },
    };

    Drupal.ajax(ajaxSettings).execute();

    return;
  }

  $.fn.iframePreviewReload = (storage, id) => {
    if (storage === 'node' && id) {
      // Reload node after save to refresh form state.
      // The content has either been modified by another user, 
      // or you have already submitted modifications. 
      // As a result, your changes cannot be saved.
      const path = `/node/${id}`
      // Reload Drupal page to refresh form state.
      window.location.href = path

      // Use once error message is fixed.
      // $iframe[0].src = src;
      // $.fn.drupalAjxax(`/composable_editor/form/node/${node}/edit?preview=${false}`);
    }

    return;
  }

  Drupal.behaviors.iframePreviewLoader = {
    attach(context) {
      const { framework, open_load, is_preview = false } = drupalSettings.composable_editor.iframe_preview;
      const { selector, node } = drupalSettings[framework].iframe_preview;
      once('composable_preview_iframe', selector, context).forEach(function () {
        if (open_load && node) {
          $.fn.drupalAjax(`/composable_editor/form/node/${node}/edit?preview=${is_preview}`);
        }
      });
    }
  };

  Drupal.behaviors.iframePreviewComposable = {
    attach() {
      window.addEventListener("message", (event) => {
        const { wrapper } = drupalSettings.composable_editor.iframe_preview;
        const { data } = event
        if (data.type === 'DRUPAL_COMPOSABLE_COMPONENT') {
          const { uuid } = data;
          const inputId = jQuery(`input[data-composable-uuid="${uuid}"]`).attr('id');
          const divSelector = 'edit-'+inputId.substring(0, inputId.indexOf("-edit--"));
          const divId = jQuery(`div[data-drupal-selector="${divSelector}"]`).attr('id');
          console.log('iframePreviewComposable', JSON.stringify(wrapper, {}, 2));

          if (wrapper.type && wrapper.mode && wrapper.selector && wrapper.position) {
            if ( wrapper.type === 'tab' && Number(wrapper.position) > 0) {
              const wrapperSelector = `${wrapper.selector} > .${wrapper.mode}-${wrapper.type}s > .${wrapper.mode}-${wrapper.type}s-list > .${wrapper.mode}-${wrapper.type}-button-${Number(wrapper.position)-1}`;
              jQuery(wrapperSelector).children(0).click();
            }
          }

          // Expand paragraph
          jQuery(`input[data-composable-uuid="${uuid}"]`).trigger("mousedown");
          // Scroll to paragraph
          document.getElementById(divId).scrollIntoView({
            behavior: 'smooth',
            block: 'start',
            inline: 'end'
          });
          event.stopImmediatePropagation();

          return;
        }
        
      }, false);
    }
  }

})(jQuery, window, Drupal, drupalSettings);
